@@ -23,6 +23,9 @@
 #define TAG_GPS_LAT        2
 #define TAG_GPS_LONG_REF   3
 #define TAG_GPS_LONG       4
+#define TAG_GPS_ALT_REF    5
+#define TAG_GPS_ALT        6
+
 
 static const char * GpsTags[MAX_GPS_TAG+1]= {
     "VersionID       ",//0x00  
@@ -67,6 +70,8 @@ void ProcessGpsInfo(unsigned char * DirStart, int ByteCount, unsigned char * Off
     unsigned a;
     int NumDirEntries;
 
+    ByteCount; // We assume byte count is big enough.
+
     NumDirEntries = Get16u(DirStart);
     #define DIR_ENTRY_ADDR(Start, Entry) (Start+2+12*(Entry))
 
@@ -77,13 +82,14 @@ void ProcessGpsInfo(unsigned char * DirStart, int ByteCount, unsigned char * Off
     ImageInfo.GpsInfoPresent = TRUE;
     strcpy(ImageInfo.GpsLat, "? ?");
     strcpy(ImageInfo.GpsLong, "? ?");
+    ImageInfo.GpsAlt[0] = 0; 
 
     for (de=0;de<NumDirEntries;de++){
         unsigned Tag, Format, Components;
         unsigned char * ValuePtr;
         int ComponentSize;
         unsigned ByteCount;
-        char * DirEntry;
+        unsigned char * DirEntry;
         DirEntry = DIR_ENTRY_ADDR(DirStart, de);
 
         Tag = Get16u(DirEntry);
@@ -115,7 +121,7 @@ void ProcessGpsInfo(unsigned char * DirStart, int ByteCount, unsigned char * Off
         }
 
         switch(Tag){
-            char FmtString[20];
+            char FmtString[21];
             char TempString[50];
             double Values[3];
 
@@ -143,8 +149,8 @@ void ProcessGpsInfo(unsigned char * DirStart, int ByteCount, unsigned char * Off
                         den = den / 10;
                         digits += 1;
                     }
-                    FmtString[1+a*7] = '2'+digits+(digits ? 1 : 0);
-                    FmtString[3+a*7] = '0'+digits;
+                    FmtString[1+a*7] = (char)('2'+digits+(digits ? 1 : 0));
+                    FmtString[3+a*7] = (char)('0'+digits);
 
                     Values[a] = ConvertAnyFormat(ValuePtr+a*ComponentSize, Format);
                 }
@@ -156,6 +162,14 @@ void ProcessGpsInfo(unsigned char * DirStart, int ByteCount, unsigned char * Off
                     strncpy(ImageInfo.GpsLong+2, TempString, 29);
                 }
                 break;
+
+            case TAG_GPS_ALT_REF:
+                ImageInfo.GpsAlt[0] = (char)(ValuePtr[0] ? '-' : ' ');
+                break;
+
+            case TAG_GPS_ALT:
+                sprintf(ImageInfo.GpsAlt + 1, "%dm", Get32s(ValuePtr));
+                break;
         }
 
         if (ShowTags){
