@@ -22,7 +22,7 @@
 #include <errno.h>
 #include <ctype.h>
 
-#define JHEAD_VERSION "2.4-2"
+#define JHEAD_VERSION "2.44"
 
 // This #define turns on features that are too very specific to 
 // how I organize my photos.  Best to ignore everything inside #ifdef MATTHIAS
@@ -278,19 +278,17 @@ static int AutoResizeCmdStuff(void)
 
     ApplyCommand = CommandString;
 
-    if (ImageInfo.Height < 800 && ImageInfo.Width < 800){
-        printf("not redizing %dx%x '%s'\n",ImageInfo.Height, ImageInfo.Width, ImageInfo.FileName);
+    if (ImageInfo.Height <= 1280 && ImageInfo.Width <= 1280){
+        printf("not resizing %dx%x '%s'\n",ImageInfo.Height, ImageInfo.Width, ImageInfo.FileName);
         return FALSE;
     }
 
-    scale = 800.0 / ImageInfo.Height;
-    if (800.0 / ImageInfo.Width < scale) scale = 800.0 / ImageInfo.Width;
+    scale = 1024.0 / ImageInfo.Height;
+    if (1024.0 / ImageInfo.Width < scale) scale = 1024.0 / ImageInfo.Width;
 
     if (scale < 0.5) scale = 0.5; // Don't scale down by more than a factor of two.
 
-    if (scale > 0.8) return FALSE; // Don't rescale by really small amounts (not worth it!)
-
-    sprintf(CommandString, "mogrify -geometry %dx%d -quality 82 &i",(int)(ImageInfo.Width*scale), (int)(ImageInfo.Height*scale));
+    sprintf(CommandString, "mogrify -geometry %dx%d -quality 85 &i",(int)(ImageInfo.Width*scale), (int)(ImageInfo.Height*scale));
     return TRUE;
 }
 
@@ -313,7 +311,7 @@ static void DoCommand(const char * FileName)
     // Make a temporary file in the destination directory by changing last char.
     strcpy(TempName, FileName);
     a = strlen(TempName)-1;
-    TempName[a] = TempName[a] == 't' ? 'z' : 't';
+    TempName[a] = (char)(TempName[a] == 't' ? 'z' : 't');
 
     // Build the exec string.  &i and &o in the exec string get replaced by input and output files.
     for (a=0;;a++){
@@ -373,7 +371,6 @@ static int CheckFileSkip(void)
         if (strstr(ImageInfo.CameraModel, FilterModel) == NULL){
             // Skip.
             return TRUE;
-
         }
     }
 
@@ -521,9 +518,9 @@ void DoFileRenaming(const char * FileName)
             // is before the '.' in ascii, and so sorting the names would put the later name before
             // the name without suffix, causing the pictures to more likely be out of order.
             if (isdigit(NewBaseName[strlen(NewBaseName)-1])){
-                NameExtra[0] = 'a'-1+a; // Try a,b,c,d... for suffix if it ends in a letter.
+                NameExtra[0] = (char)('a'-1+a); // Try a,b,c,d... for suffix if it ends in a letter.
             }else{
-                NameExtra[0] = '0'-1+a; // Try 1,2,3,4... for suffix if it ends in a char.
+                NameExtra[0] = (char)('0'-1+a); // Try 1,2,3,4... for suffix if it ends in a char.
             }
             NameExtra[1] = 0;
         }else{
@@ -561,7 +558,6 @@ void ProcessFile(const char * FileName)
     ReadMode_t ReadMode = READ_EXIF;
     CurrentFile = FileName;
     FilesMatched = 1; 
-    FileSequence += 1; // Count files processed.
 
     if (DoModify || RenameToDate || Exif2FileTime){
         if (access(FileName, 2 /*W_OK*/)){
@@ -591,6 +587,7 @@ void ProcessFile(const char * FileName)
 
     strncpy(ImageInfo.FileName, FileName, PATH_MAX);
 
+
     if (ApplyCommand || AutoRotate){
         // Applying a command is special - the headers from the file have to be
         // pre-read, then the command executed, and then the image part of the file read.
@@ -632,13 +629,13 @@ void ProcessFile(const char * FileName)
                 }
 
                 Modified = TRUE;
-                ReadMode = READ_IMAGE;   // Don't re-read exif section again on next read.
             }
         }else{
             DoCommand(FileName);
             Modified = TRUE;
-            ReadMode = READ_IMAGE;   // Don't re-read exif section again on next read.
         }
+        ReadMode = READ_IMAGE;   // Don't re-read exif section again on next read.
+
     }else if (ExifXferScrFile){
         char RelativeExifName[PATH_MAX+1];
 
@@ -664,6 +661,8 @@ void ProcessFile(const char * FileName)
         return;
     }
 
+    FileSequence += 1; // Count files processed.
+
     if (ShowConcise){
         ShowConciseImageInfo();
     }else{
@@ -927,10 +926,10 @@ void ProcessFile(const char * FileName)
     if (RenameToDate){
         DoFileRenaming(FileName);
     }
-    if(0){
-        badtime:
-        printf("Error: Time '%s': cannot convert to Unix time\n",ImageInfo.DateTime);
-    }
+    DiscardData();
+    return;
+badtime:
+    printf("Error: Time '%s': cannot convert to Unix time\n",ImageInfo.DateTime);
     DiscardData();
 }
 
@@ -1154,7 +1153,7 @@ int main (int argc, char **argv)
             DoModify = TRUE;
         }else if (!memcmp(arg,"-da",3)){
             // Date adjust feature (large time adjustments)
-            time_t NewDate, OldDate;
+            time_t NewDate, OldDate = 0;
             char * pOldDate;
             NewDate = ParseCmdDate(arg+3);
             pOldDate = strstr(arg+1, "-");
@@ -1306,6 +1305,11 @@ int main (int argc, char **argv)
             fprintf(stderr, "Error: No files matched '%s'\n",argv[argn]);
         }
     }
-    return EXIT_SUCCESS;
+    
+    if (FileSequence == 0){
+        return EXIT_FAILURE;
+    }else{
+        return EXIT_SUCCESS;
+    }
 }
 
